# automacao-blaze

Automação do site Blaze.bet usando Selenium e WebDriver Manager.

## Instalação

```bash
pip install automacao-blaze
```

## Uso

```python
from automacao_blaze import AutomacaoBlazeChrome

bot = AutomacaoBlazeChrome("email", "senha", "https://blaze.bet.br/pt/games/roleta-brasileira")
```
